#ifndef NT2_CORE_INCLUDE_FUNCTIONS_WIDTH_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_WIDTH_HPP_INCLUDED

#include <nt2/core/functions/width.hpp>
#include <nt2/core/functions/expr/width.hpp>
#include <nt2/core/functions/scalar/width.hpp>

#endif
